<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddClock</name>
    <message>
        <source>Add Log Clock</source>
        <translation type="obsolete">Legg til loggklokke</translation>
    </message>
    <message>
        <source>&amp;New Clock Name:</source>
        <translation>&amp;Namn på ny klokke:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Add Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddEvent</name>
    <message>
        <source>Add Log Event</source>
        <translation>Legg til logghending</translation>
    </message>
    <message>
        <source>&amp;New Event Name:</source>
        <translation>&amp;Namn på ny hending:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>ClockListView</name>
    <message>
        <source>Edit Event</source>
        <translation>Rediger hending</translation>
    </message>
</context>
<context>
    <name>EditClock</name>
    <message>
        <source>Edit Clock:</source>
        <translation type="obsolete">Rediger klokke:</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation>Kode:</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Slutt</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Hending</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Lengd</translation>
    </message>
    <message>
        <source>Count</source>
        <translation>Tellign</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Legg &amp;til</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>Scheduler
Rules</source>
        <translation>Planleggar-
reglar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lagra</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Lagra &amp;som</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Liste over
tene&amp;ster</translation>
    </message>
    <message>
        <source>Colo&amp;r</source>
        <translation>Fa&amp;rge</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Er du sikker på at du vil
sletta</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Slett hending</translation>
    </message>
    <message>
        <source>Clock Modified</source>
        <translation>Klokka er endra</translation>
    </message>
    <message>
        <source>The clock has been modified.
Do you want to save?</source>
        <translation>Klokka er endra.
Vil du lagra?</translation>
    </message>
    <message>
        <source>Missing Clock Code</source>
        <translation>Manglar klokkekode</translation>
    </message>
    <message>
        <source>You must specify a clock code!</source>
        <translation>Du må gje ein klokkekode!</translation>
    </message>
    <message>
        <source>Code Exists</source>
        <translation>Koden eksisterer</translation>
    </message>
    <message>
        <source>The clock code is already in use!</source>
        <translation>Klokkekoden er alt i bruk!</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Klokka eksisterer</translation>
    </message>
    <message>
        <source>Clock already exists!  Overwrite?</source>
        <translation>Klokka finst frå før! Skriv over?</translation>
    </message>
    <message>
        <source>--- End of clock ---</source>
        <translation type="obsolete">--- Slutt på klokka ---</translation>
    </message>
    <message>
        <source>Invalid Code</source>
        <translation>Ugyldig kode</translation>
    </message>
    <message>
        <source>You must provide a clock code!</source>
        <translation>Du må gje ein klokkekode!</translation>
    </message>
    <message>
        <source>Duplicate Code</source>
        <translation>Dublettkode</translation>
    </message>
    <message>
        <source>That code is already in use!</source>
        <translation>Denne koden er alt i bruk!</translation>
    </message>
    <message>
        <source>&amp;Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation type="unfinished">Rediger klokke</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That event does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER NOTES</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEvent</name>
    <message>
        <source>Editing Event</source>
        <translation>Redigerer hending</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Audio Only</source>
        <translation>Berre lyd</translation>
    </message>
    <message>
        <source>Macros Only</source>
        <translation>Berre makroar</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">KORG</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">LENGD</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTIST</translation>
    </message>
    <message>
        <source>START</source>
        <translation type="obsolete">START</translation>
    </message>
    <message>
        <source>END</source>
        <translation type="obsolete">SLUTT</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="obsolete">TYPE</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALT</translation>
    </message>
    <message>
        <source>PRE-POSITION LOG</source>
        <translation>LOGG FOR FØR-POSISJON</translation>
    </message>
    <message>
        <source>Cue to this event</source>
        <translation>Spol til denne hendinga</translation>
    </message>
    <message>
        <source>before scheduled start.  (First cart will have a STOP transition.)</source>
        <translation>før den planlagde starten (Fyrste korga får ein STOPP-overgang.)</translation>
    </message>
    <message>
        <source>TIMED START</source>
        <translation>TIDLAGT START</translation>
    </message>
    <message>
        <source>Use hard start time</source>
        <translation>Bruk hard starttid</translation>
    </message>
    <message>
        <source>Make Post Point</source>
        <translation type="obsolete">Lag Etter-punkt</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Handling viss førre hendinga spelar enno</translation>
    </message>
    <message>
        <source>Start immediately</source>
        <translation>Start med ein gong</translation>
    </message>
    <message>
        <source>Make next</source>
        <translation>Gjer til neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Krysston</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Transition if previous event ends before start time:</source>
        <translation type="obsolete">Overgang viss førre hendinga sluttar før starttida:</translation>
    </message>
    <message>
        <source>ENFORCING LENGTH</source>
        <translation>TVINGELENGD</translation>
    </message>
    <message>
        <source>Use AutoFill</source>
        <translation>Bruk Autofyll</translation>
    </message>
    <message>
        <source>Warn if fill is over or under</source>
        <translation>Åtvar viss fyllet er over eller under</translation>
    </message>
    <message>
        <source>by at least</source>
        <translation>med minst</translation>
    </message>
    <message>
        <source>Use Timescaling</source>
        <translation>Bruk tidsskalering</translation>
    </message>
    <message>
        <source>TRANSITION</source>
        <translation type="obsolete">OVERGANG</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">TELLING</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>From Traffic</source>
        <translation>Frå trafikk</translation>
    </message>
    <message>
        <source>From Music</source>
        <translation>Frå musikk</translation>
    </message>
    <message>
        <source>Select from:</source>
        <translation>Vel frå:</translation>
    </message>
    <message>
        <source>Title Separation</source>
        <translation>Titteloppdeling</translation>
    </message>
    <message>
        <source>Must have code</source>
        <translation>Må ha kode</translation>
    </message>
    <message>
        <source>Import carts scheduled</source>
        <translation>Importer korger planlagt</translation>
    </message>
    <message>
        <source>prior to the start of this event.</source>
        <translation>før starten av denne hendinga.</translation>
    </message>
    <message>
        <source>after the end of this event.</source>
        <translation>etter slutten på denne hendinga.</translation>
    </message>
    <message>
        <source>First cart has a</source>
        <translation>Fyrste korga har</translation>
    </message>
    <message>
        <source>Imported carts have a</source>
        <translation type="unfinished">Importerte korger har</translation>
    </message>
    <message>
        <source>transition.</source>
        <translation type="unfinished">ein overgang.</translation>
    </message>
    <message>
        <source>Import inline traffic with the</source>
        <translation type="obsolete">Importer innlinje-trafikk med</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ingen]</translation>
    </message>
    <message>
        <source>event.</source>
        <translation type="obsolete">hending.</translation>
    </message>
    <message>
        <source>POST-IMPORT CARTS</source>
        <translation>ETTER-IMPORT-KORGER</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lagra</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Lagra &amp;som</translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation>Liste over
tene&amp;ster</translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation>Far&amp;ge</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Event already exists!
Do you want to overwrite it?</source>
        <translation>Hendinga finst frå før!
Vil du byta henne ut?</translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation>Rediger hending</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Lyd</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Makro</translation>
    </message>
    <message>
        <source>Cue</source>
        <translation type="obsolete">Sporing</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">KRYSSTON</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">STOPP</translation>
    </message>
    <message>
        <source>OVERLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">SPEL</translation>
    </message>
    <message>
        <source>, Timed(Start)</source>
        <translation type="obsolete">, Tidlagt(Start)</translation>
    </message>
    <message>
        <source>, Timed(MakeNext)</source>
        <translation type="obsolete">, Tidlagt(Gjer-neste)</translation>
    </message>
    <message>
        <source>Timed(Wait</source>
        <translation type="obsolete">Tidlagt (Vent</translation>
    </message>
    <message>
        <source>, Post</source>
        <translation type="obsolete">, Etter</translation>
    </message>
    <message>
        <source>, Fill</source>
        <translation type="obsolete">, Fyll</translation>
    </message>
    <message>
        <source>, Scale</source>
        <translation type="obsolete">, Skalering</translation>
    </message>
    <message>
        <source>, Traffic</source>
        <translation type="obsolete">, Trafikk</translation>
    </message>
    <message>
        <source>, Music</source>
        <translation type="obsolete">, Musikk</translation>
    </message>
    <message>
        <source>, Scheduler</source>
        <translation type="obsolete">, Planleggar</translation>
    </message>
    <message>
        <source>, Inline Traffic</source>
        <translation type="obsolete">, Innlinje-trafikk</translation>
    </message>
    <message>
        <source>Len:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PRE-IMPORT CARTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IMPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Lengd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Slutt</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished">Tellign</translation>
    </message>
    <message>
        <source>Artist Separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANSITIONS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART STACK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import inline traffic event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>USER NOTES</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEventLine</name>
    <message>
        <source>Edit Event Assignment</source>
        <translation>Rediger hendingstildeling</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Hending:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vel</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Starttid:</translation>
    </message>
    <message>
        <source>End Time:</source>
        <translation>Sluttid:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Invalid Event</source>
        <translation>Ugyldig hending</translation>
    </message>
    <message>
        <source>The event end time cannot be earlier than the start time.</source>
        <translation>Sluttida for hendinga kan ikkje vera før starttida.</translation>
    </message>
    <message>
        <source>No Such Event</source>
        <translation>Inga slik hending</translation>
    </message>
    <message>
        <source>There is no such event.</source>
        <translation>Det finst ikkje noko slik hending.</translation>
    </message>
    <message>
        <source>This event overlaps with an
already existing event.</source>
        <translation>Denne hendinga overlappar
ei anna hending som finst frå før.</translation>
    </message>
</context>
<context>
    <name>EditGrid</name>
    <message>
        <source>Edit Grid:</source>
        <translation type="obsolete">Rediger gitter:</translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation>Rediger klokke</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Clear Hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change
&amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to update ALL clocks in the grid?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operation cannot be undone!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Grid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNote</name>
    <message>
        <source>Edit Log Note</source>
        <translation>Rediger loggnote</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>EditPerms</name>
    <message>
        <source>Service Associations</source>
        <translation>Tenestesameiningar</translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation>Tilgjengelege tenester</translation>
    </message>
    <message>
        <source>Enabled Services</source>
        <translation>Påskrudde tenester</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>EditSchedCodeRules</name>
    <message>
        <source>Edit Rules for Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="unfinished">Kode:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="unfinished">Maks på ei rad:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="unfinished">Min. venting:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="unfinished">Ikkje planlegg etter:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="unfinished">Eller etter:</translation>
    </message>
</context>
<context>
    <name>EditSchedRules</name>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importer</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>CODE</source>
        <translation>KODE</translation>
    </message>
    <message>
        <source>MAX. IN A ROW</source>
        <translation>MAKS PÅ EI RAD</translation>
    </message>
    <message>
        <source>MIN. WAIT</source>
        <translation>MINSTE VENTING</translation>
    </message>
    <message>
        <source>DO NOT SCHEDULE AFTER</source>
        <translation>IKKJE PLANLEGG ETTER</translation>
    </message>
    <message>
        <source>OR AFTER</source>
        <translation>ELLER ETTER</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>SKILDRING</translation>
    </message>
    <message>
        <source>Scheduler Codes:</source>
        <translation>Planleggarkodar:</translation>
    </message>
    <message>
        <source>Rules Modified</source>
        <translation>Reglane er endra</translation>
    </message>
    <message>
        <source>The rules have been modified.
Do you want to save?</source>
        <translation>Reglane er endra.
Vil du lagra?</translation>
    </message>
    <message>
        <source>Scheduler Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist Separation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Rules from Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Ingen</translation>
    </message>
    <message>
        <source>(This setting is deprecated and has been moved to events)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Rediger markør for røyst-spor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
</context>
<context>
    <name>GenerateLog</name>
    <message>
        <source>Generate Log</source>
        <translation type="unfinished">Lag logg</translation>
    </message>
    <message>
        <source>Generating Log...</source>
        <translation>Lagar logg...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Tenest:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Dato:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>&amp;Create New Log</source>
        <translation>Lag &amp;Ny logg</translation>
    </message>
    <message>
        <source>Merge &amp;Music</source>
        <translation>Flett &amp;Musikk</translation>
    </message>
    <message>
        <source>Merge &amp;Traffic</source>
        <translation>Flett &amp;Trafikk</translation>
    </message>
    <message>
        <source>Import Data</source>
        <translation>Importer data</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tilgjengeleg</translation>
    </message>
    <message>
        <source>Merged</source>
        <translation>Fletta</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>The log for</source>
        <translation>Loggen for</translation>
    </message>
    <message>
        <source>already exists.  Recreating it
will remove any merged Music or Traffic events.

Recreate?</source>
        <translation type="obsolete">finst alt. Om du lagar han på nytt,
vil det fjerna alle innfletta Musikk- eller Trafikk-hendingar.

Lag på nytt?</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Loggen eksisterer</translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Dette slettar òg</translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="obsolete">røystspor som er kopla til denne loggen.
Hald fram?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>Sporet eksisterer</translation>
    </message>
    <message>
        <source>No Errors</source>
        <translation type="unfinished">Ingen feil</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation type="obsolete">Fann ingen unntak.</translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.
Remerging it will remove this data.  Remerge?</source>
        <translation type="obsolete">inneheld alt fletta musikk- og/eller trafikkdata.
Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
    </message>
    <message>
        <source>Music Exists</source>
        <translation>Musikken eksisterer</translation>
    </message>
    <message>
        <source>already contains merged traffic data.  Remerging it
will remove this data.  Remerge?</source>
        <translation type="obsolete">inneheld alt fletta trafikkdata.
Flettar du på nytt, vil du fjerna desse dataa. Flett på nytt?</translation>
    </message>
    <message>
        <source>Traffic Exists</source>
        <translation>Trafikken eksisterer</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to generate log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear traffic links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear music links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to link music log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to link traffic log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already exists.  Recreating it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>will remove any merged Music or Traffic events.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recreate?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remerging it will remove this data.  Remerge?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged traffic data.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cannot be relinked.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No broken rules or validation exceptions found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportListView</name>
    <message>
        <source>Insert Log Note</source>
        <translation>Set inn loggnote</translation>
    </message>
    <message>
        <source>Edit Log Note</source>
        <translation>Rediger loggnote</translation>
    </message>
    <message>
        <source>Insert Voice Track</source>
        <translation>Set inn røystspor</translation>
    </message>
    <message>
        <source>Edit Voice Track</source>
        <translation>Rediger røystspor</translation>
    </message>
    <message>
        <source>Set PLAY Transition</source>
        <translation type="obsolete">Set SPEL-overgang</translation>
    </message>
    <message>
        <source>Set SEGUE Transition</source>
        <translation type="obsolete">Set KRYSSTONING-overgang</translation>
    </message>
    <message>
        <source>Set STOP Transition</source>
        <translation type="obsolete">Set STOPP-overgang</translation>
    </message>
    <message>
        <source>Set OVERLAP Transition</source>
        <translation type="obsolete">Set OVERLAPP-overgang</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation>Markør</translation>
    </message>
    <message>
        <source>[Log Note]</source>
        <translation>[Loggnote]</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Spor</translation>
    </message>
    <message>
        <source>[Voice Track]</source>
        <translation>[Røystspor]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SPEL</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>KRYSSTON</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOPP</translation>
    </message>
    <message>
        <source>OVERLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>PLAY Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP Transition</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListClocks</name>
    <message>
        <source>Log Clocks</source>
        <translation type="unfinished">Loggklokker</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Code</source>
        <translation>Kode</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Farge</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Legg &amp;til</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Døyp om</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Reinsk</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALT</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>INGEN</translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation>Klokka eksisterer</translation>
    </message>
    <message>
        <source>An clock with that name already exists!</source>
        <translation>Det finst alt ei klokke med dette namnet!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Er du sikker på at du vil 
sletta</translation>
    </message>
    <message>
        <source>Delete Clock</source>
        <translation>Slett klokka</translation>
    </message>
    <message>
        <source>is in use in the following grid(s):</source>
        <translation type="obsolete">er i bruk av desse gitra:</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Vil du framleis sletta?</translation>
    </message>
    <message>
        <source>Clock In Use</source>
        <translation>Klokka er i bruk</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following grid(s)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListEvents</name>
    <message>
        <source>Log Events</source>
        <translation type="unfinished">Logghendingar</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenskapar</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="obsolete">Farge</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Legg &amp;til</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Døyp om</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALT</translation>
    </message>
    <message>
        <source>NONE</source>
        <translation>INGEN</translation>
    </message>
    <message>
        <source>Event Exists</source>
        <translation>Hendinga eksisterer</translation>
    </message>
    <message>
        <source>An event with that name already exists!</source>
        <translation>Det finst alt ei hending med det namnet!</translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="obsolete">Er du sikker på at du vil
sletta</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Slett hendinga</translation>
    </message>
    <message>
        <source>is in use in the following clocks:</source>
        <translation type="obsolete">er i bruk av desse klokkene:</translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation>Vil du framleis sletta?</translation>
    </message>
    <message>
        <source>Event In Use</source>
        <translation>Hendinga er i bruk</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListGrids</name>
    <message>
        <source>Log Grids</source>
        <translation>Loggitter</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Skildring</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>R&amp;ediger</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Lukk</translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Rivendell Services</source>
        <translation>Rivendell-tenester</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">TENEST</translation>
    </message>
    <message>
        <source>OLDEST REPORT</source>
        <translation type="obsolete">ELDSTE RAPPORT</translation>
    </message>
    <message>
        <source>&amp;Generate
Reports</source>
        <translation>La&amp;g
rapportar</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Tøm
data</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ingen]</translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Oldest Report</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Greier ikkje kopla til</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>Select an operation:</source>
        <translation>Vel ei handling:</translation>
    </message>
    <message>
        <source>Edit &amp;Events</source>
        <translation>Redig&amp;er hendingar</translation>
    </message>
    <message>
        <source>Edit C&amp;locks</source>
        <translation>Rediger &amp;klokker</translation>
    </message>
    <message>
        <source>Edit G&amp;rids</source>
        <translation>Rediger &amp;gitter</translation>
    </message>
    <message>
        <source>&amp;Generate Logs</source>
        <translation>Lag lo&amp;ggar</translation>
    </message>
    <message>
        <source>Manage &amp;Reports</source>
        <translation>Handter &amp;Rapportar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation>Vel rapportdatoar</translation>
    </message>
    <message>
        <source>&amp;Report:</source>
        <translation>&amp;Rapport:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Startdato:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Vel</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>Slu&amp;ttdato:</translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation>La&amp;g
rapport</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Invalid Date Range</source>
        <translation>Ugyldige datoar</translation>
    </message>
    <message>
        <source>The end date cannot be earlier than the start date!</source>
        <translation>Sluttdatoen kan ikkje vera før startdatoen!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple dates!</source>
        <translation>Denne rapporttypen kan ikkje gå over fleire datoar!</translation>
    </message>
    <message>
        <source>This report type cannot span multiple months!</source>
        <translation>Denne rapporttypen kan ikkje gå over fleire månader!</translation>
    </message>
    <message>
        <source>Report Complete</source>
        <translation type="obsolete">Rapporten ferdig</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Rapporten er ferdig!</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open report file at</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The report file already exists.  Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameItem</name>
    <message>
        <source>Rename</source>
        <translation>Døyp om</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Name Conflict</source>
        <translation>Konflikt om namn</translation>
    </message>
    <message>
        <source>That name already exists!</source>
        <translation>Det namnet finst frå før!</translation>
    </message>
</context>
<context>
    <name>SvcRec</name>
    <message>
        <source>Mo</source>
        <translation>Må</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ty</translation>
    </message>
    <message>
        <source>We</source>
        <translation>On</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>To</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Fr</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>La</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Su</translation>
    </message>
</context>
<context>
    <name>SvcRecDialog</name>
    <message>
        <source>Report Data</source>
        <translation>Rapportdata</translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation>&amp;Tøm
data</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>Delete Report Data</source>
        <translation>Slett rapportdata</translation>
    </message>
    <message>
        <source>Are you sure you want to delete report data for</source>
        <translation>Er du sikker på at du vil sletta rapportdata for</translation>
    </message>
</context>
<context>
    <name>editSchedCodeRules</name>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Avbryt</translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="obsolete">Kode:</translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="obsolete">Maks på ei rad:</translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="obsolete">Min. venting:</translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="obsolete">Ikkje planlegg etter:</translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="obsolete">Eller etter:</translation>
    </message>
</context>
</TS>
